@@ -15,15 +15,16 @@ async fn main() -> Result<(), AteError> {
     ate::log_init(opts.verbose, opts.debug);
 
     // Determine what we need to do
+    let auth = ate_auth::prelude::origin_url(&opts.auth, "auth");
     match opts.subcmd {
         SubCommand::User(opts_user) => {
-            main_opts_user(opts_user, opts.token, opts.token_path, opts.auth).await?;
+            main_opts_user(opts_user, opts.token, opts.token_path, auth).await?;
         }
         SubCommand::Group(opts_group) => {
-            main_opts_group(opts_group, opts.token, opts.token_path, opts.auth, "Group").await?;
+            main_opts_group(opts_group, opts.token, opts.token_path, auth, "Group").await?;
         }
         SubCommand::Token(opts_token) => {
-            main_opts_token(opts_token, opts.token, opts.token_path, opts.auth, "Group").await?;
+            main_opts_token(opts_token, opts.token, opts.token_path, auth, "Group").await?;
         }
     }
 
